==> stackwriter-api-0.0.1-sources.jar: net/sozal/stackwriter/api/domain/Frame.java <==
package net.sozal.stackwriter.api.domain;

import java.lang.reflect.Method;
import java.util.Arrays;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;

/**
 * @author serkan
 */
public final class Frame {

    private final Method method;
    private final LocalVariable[] locals;

    public Frame(Method method, LocalVariable[] locals) {
        this.method = method;
        this.locals = locals;
    }

    public Method getMethod() {
        return method;
    }

    public Map<String, Object> getLocals() {
        if (locals == null || locals.length == 0) {
            return Collections.emptyMap();
        }

        Map<String, Object> localsMap = new HashMap<>();
        for (Frame.LocalVariable localVariable : locals) {
            if (localVariable != null) {
                localsMap.put(localVariable.getName(), localVariable.getValue());
            }
        }

        return localsMap;
    }

    @Override
    public String toString() {
        return "Frame{"
            + "method=" + method.getDeclaringClass().getName() + "." + method.getName()
            + ", locals=" + Arrays.toString(locals)
            + '}';
    }

    public static final class LocalVariable {

        final String name;
        final Object value;

        public LocalVariable(String name, Object value) {
            this.name = name;
            this.value = value;
        }

        public String getName() {
            return name;
        }

        public Object getValue() {
            return value;
        }

        @Override
        public String toString() {
            return "LocalVariable{"
                + "name='" + name + '\''
                + ", value=" + value
                + '}';
        }

    }

}

==> stackwriter-api-0.0.2-sources.jar: net/sozal/stackwriter/api/domain/Frame.java <==
package net.sozal.stackwriter.api.domain;

import java.lang.reflect.Method;
import java.util.Arrays;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;

/**
 * @author serkan
 */
public final class Frame {

    private final Class clazz;
    private final Method method;
    private final int line;
    private final LocalVariable[] locals;

    public Frame(Class<?> clazz, Method method, int line, LocalVariable[] locals) {
        this.clazz = clazz;
        this.method = method;
        this.line = line;
        this.locals = locals;
    }

    public Class getClazz() {
        return clazz;
    }

    public Method getMethod() {
        return method;
    }

    public int getLine() {
        return line;
    }

    public Map<String, Object> getLocals() {
        if (locals == null || locals.length == 0) {
            return Collections.emptyMap();
        }

        Map<String, Object> localsMap = new HashMap<>();
        for (Frame.LocalVariable localVariable : locals) {
            if (localVariable != null) {
                localsMap.put(localVariable.getName(), localVariable.getValue());
            }
        }

        return localsMap;
    }

    @Override
    public String toString() {
        return "Frame{"
            + "class=" + clazz.getName()
            + ", method=" + method.getDeclaringClass().getName() + "." + method.getName()
            + ", lineNo=" + line
            + ", locals=" + Arrays.toString(locals)
            + '}';
    }

    public static final class LocalVariable {

        final String name;
        final Object value;

        public LocalVariable(String name, Object value) {
            this.name = name;
            this.value = value;
        }

        public String getName() {
            return name;
        }

        public Object getValue() {
            return value;
        }

        @Override
        public String toString() {
            return "LocalVariable{"
                + "name='" + name + '\''
                + ", value=" + value
                + '}';
        }

    }

}
